==> haskell-zlib-0.6.3.0-60-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib
version:              0.6.3.0
visibility:           public
id:                   zlib-0.6.3.0-7eb8DNb2CEF4EgehmrZW7c
key:                  zlib-0.6.3.0-7eb8DNb2CEF4EgehmrZW7c
license:              BSD-3-Clause
copyright:            (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:             Codec
abi:                  826c1423ff1e9bdd75e6241f1f7a7ef1
exposed:              True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:          /usr/lib/ghc-9.2.8/site-local/zlib-0.6.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/zlib-0.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib
hs-libraries:         HSzlib-0.6.3.0-7eb8DNb2CEF4EgehmrZW7c
extra-libraries:      z
includes:             zlib.h
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:   /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:         /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-0.6.3.0-62-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib
version:              0.6.3.0
visibility:           public
id:                   zlib-0.6.3.0-AuZles6iZ6jGNBHTmlcghA
key:                  zlib-0.6.3.0-AuZles6iZ6jGNBHTmlcghA
license:              BSD-3-Clause
copyright:            (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:             Codec
abi:                  57551b50ebce4ce21190cf32c88c1878
exposed:              True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:          /usr/lib/ghc-9.2.8/site-local/zlib-0.6.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/zlib-0.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib
hs-libraries:         HSzlib-0.6.3.0-AuZles6iZ6jGNBHTmlcghA
extra-libraries:      z
includes:             zlib.h
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:   /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:         /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
